@@ -311,7 +311,7 @@ append_stock_menuitem (GtkWidget  *menu,
                            NULL, &error);
   if (error)
     {
-      g_printerr (_("There was an error subscribing to notification of menu icon visibilty changes. (%s)\n"), error->message);
+      g_printerr (_("There was an error subscribing to notification of menu icon visibility changes. (%s)\n"), error->message);
       g_error_free (error);
     }
 
@@ -1610,8 +1610,6 @@ terminal_window_set_active (TerminalWindow *window,
 #endif
   terminal_window_set_size (window, screen, TRUE);
   
-  gtk_widget_grab_focus (terminal_screen_get_widget (window->priv->active_term));
-
   fill_in_config_picker_submenu (window);
   fill_in_new_term_submenus (window);
   update_zoom_items (window);
@@ -2336,30 +2334,11 @@ fullscreen_callback (GtkWidget      *menuitem,
     {
       static GtkWidget *no_fullscreen_dialog = NULL;
 
-      if (no_fullscreen_dialog == NULL)
-        {
-          no_fullscreen_dialog =
-            gtk_message_dialog_new (GTK_WINDOW (window),
-                                    GTK_DIALOG_DESTROY_WITH_PARENT,
-                                    GTK_MESSAGE_ERROR,
-                                    GTK_BUTTONS_CLOSE,
+      terminal_util_show_error_dialog (GTK_WINDOW (window), &no_fullscreen_dialog,
                                     _("Your current desktop environment does not support the full screen feature.\n (In technical terms, you need a window manager with support for the _NET_WM_STATE_FULLSCREEN property.)"));
-          
-          g_object_add_weak_pointer (G_OBJECT (no_fullscreen_dialog),
-                                     (void**) &no_fullscreen_dialog);
-
-          g_signal_connect (G_OBJECT (no_fullscreen_dialog), "response",
-                            G_CALLBACK (gtk_widget_destroy),
-                            NULL);
-        }
-      
-      gtk_window_present (GTK_WINDOW (no_fullscreen_dialog));
-
-      return;
     }
-  
-  terminal_window_set_fullscreen (window,
-                                  !terminal_window_get_fullscreen (window));
+  else 
+    terminal_window_set_fullscreen (window, !terminal_window_get_fullscreen (window));
 }
 
 static double zoom_factors[] = {
@@ -2591,23 +2570,8 @@ help_callback (GtkWidget      *menuitem,
 
   if (err != NULL)
     {
-      GtkWidget *dialog;
-      
-      dialog = gtk_message_dialog_new (GTK_WINDOW (window),
-                                       GTK_DIALOG_DESTROY_WITH_PARENT,
-                                       GTK_MESSAGE_ERROR,
-                                       GTK_BUTTONS_CLOSE,
-                                       _("There was an error displaying help: %s"),
-                                       err->message);
-      
-      g_signal_connect (G_OBJECT (dialog), "response",
-                        G_CALLBACK (gtk_widget_destroy),
-                        NULL);
-      
-      gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
-      
-      gtk_widget_show (dialog);
-
+      terminal_util_show_error_dialog (GTK_WINDOW (window), NULL,
+                                       _("There was an error displaying help: %s"), err->message);
       g_error_free (err);
     }
 }
@@ -2622,6 +2586,7 @@ about_callback (GtkWidget      *menuitem,
 
   const char *authors[] = {
     "Havoc Pennington <hp@redhat.com>",
+    "Mariano Su\303\241rez-Alvarez <msuarezalvarez@arnet.com.ar>",
     NULL
   };
   const char *documenters [] = {
@@ -2639,9 +2604,9 @@ about_callback (GtkWidget      *menuitem,
   pixbuf = gdk_pixbuf_new_from_file (file, NULL);
   g_free(file);
 
-  about = gnome_about_new (PACKAGE, VERSION,
+  about = gnome_about_new (_("GNOME Terminal"), VERSION,
                            "Copyright \xc2\xa9 2002 Havoc Pennington",
-                           _("GNOME Terminal"),
+                           NULL,
                            (const char **)authors,
                            (const char **)documenters,
                            strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
